==> igniteui-react-charts-16.6.4.tgz: package/ES5/NegativeVolumeIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { NegativeVolumeIndexIndicatorStrategy } from "./NegativeVolumeIndexIndicatorStrategy";
import { markType } from "igniteui-react-core/ES5/type";
var NegativeVolumeIndexIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(NegativeVolumeIndexIndicator, _super);
    function NegativeVolumeIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NegativeVolumeIndexIndicator.prototype.get_p3 = function () {
        return new NegativeVolumeIndexIndicatorStrategy();
    };
    Object.defineProperty(NegativeVolumeIndexIndicator.prototype, "p3", {
        get: function () {
            return this.get_p3();
        },
        enumerable: true,
        configurable: true
    });
    NegativeVolumeIndexIndicator.prototype.get_qg = function () {
        return NegativeVolumeIndexIndicator.$;
    };
    Object.defineProperty(NegativeVolumeIndexIndicator.prototype, "qg", {
        get: function () {
            return this.get_qg();
        },
        enumerable: true,
        configurable: true
    });
    NegativeVolumeIndexIndicator.$t = markType(NegativeVolumeIndexIndicator, 'NegativeVolumeIndexIndicator', StrategyBasedIndicator.$);
    return NegativeVolumeIndexIndicator;
}(StrategyBasedIndicator));
export { NegativeVolumeIndexIndicator };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/NegativeVolumeIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { NegativeVolumeIndexIndicatorStrategy } from "./NegativeVolumeIndexIndicatorStrategy";
import { markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var NegativeVolumeIndexIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(NegativeVolumeIndexIndicator, _super);
    function NegativeVolumeIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NegativeVolumeIndexIndicator.prototype.get_p5 = function () {
        return new NegativeVolumeIndexIndicatorStrategy();
    };
    Object.defineProperty(NegativeVolumeIndexIndicator.prototype, "p5", {
        get: function () {
            return this.get_p5();
        },
        enumerable: true,
        configurable: true
    });
    NegativeVolumeIndexIndicator.prototype.get_qi = function () {
        return NegativeVolumeIndexIndicator.$;
    };
    Object.defineProperty(NegativeVolumeIndexIndicator.prototype, "qi", {
        get: function () {
            return this.get_qi();
        },
        enumerable: true,
        configurable: true
    });
    NegativeVolumeIndexIndicator.$t = markType(NegativeVolumeIndexIndicator, 'NegativeVolumeIndexIndicator', StrategyBasedIndicator.$);
    return NegativeVolumeIndexIndicator;
}(StrategyBasedIndicator));
export { NegativeVolumeIndexIndicator };
